@@ -1,4 +1,4 @@
-# Copyright 2019 Cambridge Quantum Computing
+# Copyright 2019-2020 Cambridge Quantum Computing
 #
 # Licensed under a Non-Commercial Use Software Licence (the "Licence");
 # you may not use this file except in compliance with the Licence.
@@ -13,5 +13,6 @@
 # See the Licence for the specific language governing permissions and
 # limitations under the Licence, but note it is strictly for non-commercial use.
 """Module for conversion between IBM Qiskit and :math:`\\mathrm{t|ket}\\rangle` primitives."""
-from .qiskit_convert import qiskit_to_tk, tk_to_qiskit
-# from .tket_pass import TketPass
\ No newline at end of file
+from .qiskit_convert import qiskit_to_tk, tk_to_qiskit, process_device
+
+# from .tket_pass import TketPass
