@@ -1,4 +1,4 @@
-# Copyright 2019 Cambridge Quantum Computing
+# Copyright 2019-2020 Cambridge Quantum Computing
 #
 # Licensed under a Non-Commercial Use Software Licence (the "Licence");
 # you may not use this file except in compliance with the Licence.
@@ -25,32 +25,40 @@ from typing import Optional
 from pytket.passes import BasePass, OptimisePhaseGadgets, SequencePass
 from pytket.predicates import CompilationUnit
 from .qiskit_convert import qiskit_to_tk, tk_to_qiskit, process_device
-from pytket.backends.ibm import IBMQBackend, AerBackend, AerStateBackend, AerUnitaryBackend
+from pytket.backends.ibm import (
+    IBMQBackend,
+    AerBackend,
+    AerStateBackend,
+    AerUnitaryBackend,
+)
+
 
 class TketPass(TransformationPass):
     """The :math:`\\mathrm{t|ket}\\rangle` compiler to be plugged in to the Qiskit compilation sequence"""
+
     filecount = 0
     _aer_backend_map = {
-        'QasmSimulator': AerBackend,
-        'StatevectorSimulator': AerStateBackend,
-        'UnitarySimulator': AerUnitaryBackend
+        "QasmSimulator": AerBackend,
+        "StatevectorSimulator": AerStateBackend,
+        "UnitarySimulator": AerUnitaryBackend,
     }
-    def __init__(self, backend:BaseBackend, tket_pass:Optional[BasePass]=None) :
+
+    def __init__(self, backend: BaseBackend, tket_pass: Optional[BasePass] = None):
         """Wraps a pytket compiler pass as a :py:class:`qiskit.transpiler.TransformationPass`.
         A :py:class:`qiskit.dagcircuit.DAGCircuit` is converted to a pytket :py:class:`Circuit`.
         If specified, `tket_pass` will be run, otherwise a default pass is used. The circuit is
         then routed and rebased for the `backend`, and converted back.
-        
+
         :param backend: The Qiskit backend to target
         :type backend: BaseBackend
         :param tket_pass: The pytket compiler pass to run. Defaults to None
         :type tket_pass: Optional[BasePass], optional
         """
         qBasePass.__init__(self)
-        if not isinstance(backend, BaseBackend) :
+        if not isinstance(backend, BaseBackend):
             raise ValueError("Requires BaseBackend instance")
 
-        if not tket_pass :
+        if not tket_pass:
             tket_pass = OptimisePhaseGadgets()
         passlist = [tket_pass]
         if isinstance(backend._provider, AerProvider):
@@ -63,7 +71,7 @@ class TketPass(TransformationPass):
         passlist.append(tk_backend.default_compilation_pass)
         self._pass = SequencePass(passlist)
 
-    def run(self, dag:DAGCircuit) -> DAGCircuit :
+    def run(self, dag: DAGCircuit) -> DAGCircuit:
         """Run a preconfigured optimisation pass on the circuit and route for the given backend.
 
         :param dag: The circuit to optimise and route
